==> go.php?file=RaidAchievement1.075.zip: RaidAchievement/Localization/localization-zhCN.lua <==
﻿if GetLocale() == "zhCN" then


function psealocale()


	ramaintrackingtitle = "追踪中"
	ramanyachtitinfo = "当成就失败时，当前的战斗中将会停止继续追踪。这个模块重启这个功能，在'失败信息'出现后的 "
	ramanyachtitinfo2 = "后继续追踪。下面可设定战斗中你想重启几次追踪，并按下'开始'模块。这个模块会在登出后自动关闭。"
	ramanyachtitinfoq = "战斗中将会重启 "
	ramanyachtitinfoq2 = "次追踪。下面可修改次数："
	raminibuttset = "显示小地图图标"
	ramodulnotblock = "追踪将不会停止"
	ranewversfound = "|cff00ff00注意！|r 发现新版本，推荐到 www.phoenixstyle.com 更新插件"
	rasec = "秒。"
	ratitleaddbutk3 = "主选项" -- Needs review
	ratitleaddk3 = "    主插件选项" -- Needs review
	ravalitnottrack = "插件不追踪英雄模式"
	ut_3 = "主选项"
	whraaddkilled1 = "小怪已击杀！"
	whraaddkilled2 = "现在击杀首领将不能完成成就！"
	whrabrann = "布莱恩·铜须"
	whrabrannemo = "你想跟我来硬的？"
	whrabrannemo2 = "安全系统自动修复装置已被关闭。立刻消除化全部存储器内容并……"
	whragundemo = "我要把你碎尸万断"
	PSFeaserver = "CN-斯坦索姆-Adavak"
	charakillintime = "所需条件完成！首领3层闪电充能堆叠（30秒剩余），击杀！"
	charakillintime2 = "所需条件完成！首领有此状态（20秒剩余），击杀！"
	chhrbrannyell = "好啊，我们走！只需要在门禁系统中输入最终登录序列……然后……"
	chratitle = "    大地的裂变英雄"
	crraraidpartachloc1 = "静电震击！"
	crraraidpartachloc2 = "毒液炸弹！"
	crraraidpartachloc3 = "奥术歼灭者！"
	crraraidpartachloc4 = "火焰喷射器！"
	crratitle = "    大地的裂变团队 - T11"
	icravalitriayell1 = "我打开了进入梦境的传送门。英雄们，救赎就在其中……"
	icravalitriayell2 = "我获得了新生！伊瑟拉的恩泽赐予我消灭邪恶的力量！"
	nrallbuttonmaint = "区域列表"
	nrallbuttontak = "战术"
	nxraonyemote = "深深地吸了一口气"
	nxraonyxiab = "奥妮克希亚"
	psbuttonoff = "停止"
	psbuttonon = "开始"
	pseaaddonmy = "插件"
	pseaaddonoff = "关闭"
	pseaaddonok = "好"
	pseaaddonon = "启用插件"
	pseaaddonon2 = "开启"
	pseachangeall = "反向选择"
	pseachatlist1 = "团队"
	pseachatlist2 = "团队警报"
	pseachatlist3 = "官员"
	pseachatlist4 = "小队"
	pseachatlist5 = "公会"
	pseachatlist6 = "说"
	pseachatlist7 = "大喊"
	pseachatlist8 = "自身"
	pseadisableall = "全部开启"
	pseaenableall = "全部关闭"
	psealeftmenu1 = "插件"
	psealeftmenu11 = "失败后追踪"
	psealeftmenu3 = "纳克萨玛斯"
	psealeftmenu31 = "纳克萨玛斯 + 其他巫妖王团队"
	psealeftmenu4 = "巫妖王之怒地下城"
	psealeftmenu5 = "奥杜尔"
	psealeftmenu6 = "冰冠堡垒"
	psealeftmenucata = "大地的裂变英雄"
	psealeftmenucata2 = "大地的裂变团队 - T11"
	pseamanyachtitle = "    失败后继续追踪成就"
	pseamoduleload = "模块已加载："
	pseamodulenotload = "加载模块时出错："
	pseapartfailedloc = "部分已失败！"
	pseapsaddonanet = "错误！未安装 PhoenixStyle 插件"
	pseapsaddonanet2 = "你可以在 www.ps-addon.com 下载此插件"
	pseareports = "- 在此频道中公布警报"
	pseashownames = "显示成就失败的原因（名字或其他）"
	pseashowveren = "显示更新通知"
	pseasoundoptions1 = "成就失败时播放音效"
	pseasoundoptions2 = "成就所需成功时播放音效"
	pseasoundoptions3 = "只对所需成就播放音效"
	pseasoundoptions6 = "专家模式，当游戏内音效被禁用时播放音效"
	pseatreb2 = "所需条件完成！击杀首领吧！"
	pseatreb4 = "失败！"
	pseatrebulda2 = "击杀最后一个小怪后击杀首领！"
	pseauierror = "    错误！"
	pseauierroraddonoff = "错误！插件已关闭 - 此模块不可用！"
	pseauinomodule1 = "    错误！未安装模块！"
	pseauinomodule2 = "错误！所选模块未安装！"
	psmoduletxtoff = "模块已关闭"
	psmoduletxton = "模块已开启"
	psoldvertxt = "（旧版本）"
	raiccof = "的"
	raiccused = "已用"



end


end

==> go.php?file=RaidAchievement1.079.zip: RaidAchievement/Localization/localization-zhCN.lua <==
﻿if GetLocale() == "zhCN" then


function psealocale()


	ramaintrackingtitle = "追踪中"
	ramanyachtitinfo = "当成就失败时，当前的战斗中将会停止继续追踪。这个模块重启这个功能，在'失败信息'出现后的 "
	ramanyachtitinfo2 = "后继续追踪。下面可设定战斗中你想重启几次追踪，并按下'开始'模块。这个模块会在登出后自动关闭。"
	ramanyachtitinfoq = "战斗中将会重启 "
	ramanyachtitinfoq2 = "次追踪。下面可修改次数："
	raminibuttset = "显示小地图图标"
	ramodulnotblock = "追踪将不会停止"
	ranewversfound = "|cff00ff00注意！|r 发现新版本，推荐到 www.phoenixstyle.com 更新插件"
	rasec = "秒。"
	ratitleaddbutk3 = "主选项" -- Needs review
	ratitleaddk3 = "    主插件选项" -- Needs review
	ravalitnottrack = "插件不追踪英雄模式"
	ut_3 = "主选项"
	whraaddkilled1 = "小怪已击杀！"
	whraaddkilled2 = "现在击杀首领将不能完成成就！"
	whrabrann = "布莱恩·铜须"
	whrabrannemo = "你想跟我来硬的？"
	whrabrannemo2 = "安全系统自动修复装置已被关闭。立刻消除化全部存储器内容并……"
	whragundemo = "我要把你碎尸万断"
	PSFeaserver = "CN-斯坦索姆-Adavak"
	charakillintime = "所需条件完成！首领3层闪电充能堆叠（30秒剩余），击杀！"
	charakillintime2 = "所需条件完成！首领有此状态（20秒剩余），击杀！"
	chhrbrannyell = "好啊，我们走！只需要在门禁系统中输入最终登录序列……然后……"
	chratitle = "    大地的裂变英雄"
	crraraidpartachloc1 = "静电震击！"
	crraraidpartachloc2 = "毒液炸弹！"
	crraraidpartachloc3 = "奥术歼灭者！"
	crraraidpartachloc4 = "火焰喷射器！"
	crratitle = "    大地的裂变团队"
	icravalitriayell1 = "我打开了进入梦境的传送门。英雄们，救赎就在其中……"
	icravalitriayell2 = "我获得了新生！伊瑟拉的恩泽赐予我消灭邪恶的力量！"
	nrallbuttonmaint = "区域列表"
	nrallbuttontak = "战术"
	nxraonyemote = "深深地吸了一口气"
	nxraonyxiab = "奥妮克希亚"
	psbuttonoff = "停止"
	psbuttonon = "开始"
	pseaaddonmy = "插件"
	pseaaddonoff = "关闭"
	pseaaddonok = "好"
	pseaaddonon = "启用插件"
	pseaaddonon2 = "开启"
	pseachangeall = "反向选择"
	pseachatlist1 = "团队"
	pseachatlist2 = "团队警报"
	pseachatlist3 = "官员"
	pseachatlist4 = "小队"
	pseachatlist5 = "公会"
	pseachatlist6 = "说"
	pseachatlist7 = "大喊"
	pseachatlist8 = "自身"
	pseadisableall = "全部开启"
	pseaenableall = "全部关闭"
	psealeftmenu1 = "插件"
	psealeftmenu11 = "失败后追踪"
	psealeftmenu3 = "纳克萨玛斯"
	psealeftmenu31 = "纳克萨玛斯 + 其他巫妖王团队"
	psealeftmenu4 = "巫妖王之怒地下城"
	psealeftmenu5 = "奥杜尔"
	psealeftmenu6 = "冰冠堡垒"
	psealeftmenucata = "大地的裂变英雄"
	psealeftmenucata2 = "大地的裂变团队"
	pseamanyachtitle = "    失败后继续追踪成就"
	pseamoduleload = "模块已加载："
	pseamodulenotload = "加载模块时出错："
	pseapartfailedloc = "部分已失败！"
	pseapsaddonanet = "错误！未安装 PhoenixStyle 插件"
	pseapsaddonanet2 = "你可以在 www.ps-addon.com 下载此插件"
	pseareports = "- 在此频道中公布警报"
	pseashownames = "显示成就失败的原因（名字或其他）"
	pseashowveren = "显示更新通知"
	pseasoundoptions1 = "成就失败时播放音效"
	pseasoundoptions2 = "成就所需成功时播放音效"
	pseasoundoptions3 = "只对所需成就播放音效"
	pseasoundoptions6 = "专家模式，当游戏内音效被禁用时播放音效"
	pseatreb2 = "所需条件完成！击杀首领吧！"
	pseatreb4 = "失败！"
	pseatrebulda2 = "击杀最后一个小怪后击杀首领！"
	pseauierror = "    错误！"
	pseauierroraddonoff = "错误！插件已关闭 - 此模块不可用！"
	pseauinomodule1 = "    错误！未安装模块！"
	pseauinomodule2 = "错误！所选模块未安装！"
	psmoduletxtoff = "模块已关闭"
	psmoduletxton = "模块已开启"
	psoldvertxt = "（旧版本）"
	raiccof = "的"
	raiccused = "已用"



end


end
